@@ -3,16 +3,26 @@ from github2.issues import Issues
 from github2.repositories import Repositories
 from github2.users import Users
 from github2.commits import Commits
+from github2.organizations import Organizations
+from github2.teams import Teams
 
 
 class Github(object):
 
     def __init__(self, username=None, api_token=None, debug=False,
-        requests_per_second=None, access_token=None, cache=None):
+        requests_per_second=None, access_token=None, cache=None,
+        proxy_host=None, proxy_port=8080):
         """
         An interface to GitHub's API:
             http://develop.github.com/
 
+        .. versionadded:: 0.2.0
+           The ``requests_per_second`` parameter
+        .. versionadded:: 0.3.0
+           The ``cache`` and ``access_token`` parameters
+        .. versionadded:: 0.4.0
+           The ``proxy_host`` and ``proxy_port`` parameters
+
         :param str username: your own GitHub username.
         :param str api_token: can be found at https://github.com/account
             (while logged in as that user):
@@ -24,17 +34,24 @@ class Github(object):
             or None to disable delays.  The default is to disable delays (for
             backwards compatibility).
         :param str cache: a directory for caching GitHub responses.
+        :param str proxy_host: the hostname for the HTTP proxy, if needed.
+        :param str proxy_port: the hostname for the HTTP proxy, if needed (will
+            default to 8080 if a proxy_host is set and no port is set).
         """
 
         self.debug = debug
         self.request = GithubRequest(username=username, api_token=api_token,
                                      debug=self.debug,
                                      requests_per_second=requests_per_second,
-                                     access_token=access_token, cache=cache)
+                                     access_token=access_token, cache=cache,
+                                     proxy_host=proxy_host,
+                                     proxy_port=proxy_port)
         self.issues = Issues(self.request)
         self.users = Users(self.request)
         self.repos = Repositories(self.request)
         self.commits = Commits(self.request)
+        self.organizations = Organizations(self.request)
+        self.teams = Teams(self.request)
 
     def project_for_user_repo(self, user, repo):
         """Return Github identifier for a user's repository
@@ -47,6 +64,8 @@ class Github(object):
     def get_all_blobs(self, project, tree_sha):
         """Get a list of all blobs for a specific tree
 
+        .. versionadded:: 0.3.0
+
         :param str project: GitHub project
         :param str tree_sha: object ID of tree
         """
